Module: RDF::Oxigraph
- Defined in:
- lib/rdf/oxigraph/shacl.rb,
lib/rdf/oxigraph/format.rb,
lib/rdf/oxigraph/sparql.rb,
lib/rdf/oxigraph/version.rb,
lib/rdf/oxigraph/conversion.rb,
lib/rdf/oxigraph/repository.rb
Defined Under Namespace
Modules: Conversion, SHACL, SPARQL Classes: JsonLd, JsonLdReader, JsonLdWriter, NQuads, NQuadsReader, NQuadsWriter, NTriples, NTriplesReader, NTriplesWriter, Reader, Repository, TriG, TriGReader, TriGWriter, Turtle, TurtleReader, TurtleWriter, Writer
Constant Summary collapse
- FORMATS =
Native-format strings keyed by RDF.rb format symbol.
{ turtle: "turtle", ttl: "turtle", ntriples: "ntriples", nquads: "nquads", trig: "trig", rdfxml: "rdfxml", jsonld: "jsonld" }.freeze
- VERSION =
"0.0.1"
Class Method Summary collapse
-
.native_format(format) ⇒ Object
Map an RDF.rb format symbol (or content type / file name) to the native oxigraph format string, or nil if unsupported.
Class Method Details
.native_format(format) ⇒ Object
Map an RDF.rb format symbol (or content type / file name) to the native oxigraph format string, or nil if unsupported.
16 17 18 19 20 21 |
# File 'lib/rdf/oxigraph/format.rb', line 16 def self.native_format(format) return FORMATS[format] if format.is_a?(Symbol) fmt = RDF::Format.for(format) fmt && FORMATS[fmt.to_sym] end |